"""Constants for the Heinrich-Hertz-Schule Vertretungsplan API."""

BASE_URL = "https://www.heinrich-hertz-schule-hamburg.de/"
LOGIN_URL = BASE_URL + "OnlineVertretungsplan.php"
LOGIN_TEXT = "angemeldet als"
KEY_ALLE = "_"